==> SDL2-2.0.18.tar.gz: SDL2-2.0.18/src/loadso/dummy/SDL_sysloadso.c <==
/*
  Simple DirectMedia Layer
  Copyright (C) 1997-2021 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
#include "../../SDL_internal.h"

#if defined(SDL_LOADSO_DUMMY) || defined(SDL_LOADSO_DISABLED)

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* System dependent library loading routines                           */

#include "SDL_loadso.h"

void *
SDL_LoadObject(const char *sofile)
{
    const char *loaderror = "SDL_LoadObject() not implemented";
    SDL_SetError("Failed loading %s: %s", sofile, loaderror);
    return (NULL);
}

void *
SDL_LoadFunction(void *handle, const char *name)
{
    const char *loaderror = "SDL_LoadFunction() not implemented";
    SDL_SetError("Failed loading %s: %s", name, loaderror);
    return (NULL);
}

void
SDL_UnloadObject(void *handle)
{
    /* no-op. */
}

#endif /* SDL_LOADSO_DUMMY || SDL_LOADSO_DISABLED */

/* vi: set ts=4 sw=4 expandtab: */

==> SDL2-2.28.1.tar.gz: SDL2-2.28.1/src/loadso/dummy/SDL_sysloadso.c <==
/*
  Simple DirectMedia Layer
  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
#include "../../SDL_internal.h"

#if defined(SDL_LOADSO_DUMMY) || defined(SDL_LOADSO_DISABLED)

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* System dependent library loading routines                           */

#include "SDL_loadso.h"

void *SDL_LoadObject(const char *sofile)
{
    const char *loaderror = "SDL_LoadObject() not implemented";
    SDL_SetError("Failed loading %s: %s", sofile, loaderror);
    return NULL;
}

void *SDL_LoadFunction(void *handle, const char *name)
{
    const char *loaderror = "SDL_LoadFunction() not implemented";
    SDL_SetError("Failed loading %s: %s", name, loaderror);
    return NULL;
}

void SDL_UnloadObject(void *handle)
{
    /* no-op. */
}

#endif /* SDL_LOADSO_DUMMY || SDL_LOADSO_DISABLED */

/* vi: set ts=4 sw=4 expandtab: */
